@@ -10,6 +10,6 @@ from graphgallery.nn.layers.top_k import Top_k_features
 from graphgallery.nn.layers.lgcn import LGConvolution
 from graphgallery.nn.layers.edgeconv import GraphEdgeConvolution
 from graphgallery.nn.layers.mediansage import MedianAggregator, MedianGCNAggregator
-from graphgallery.nn.layers.gcnf import GraphConvFeature
+from graphgallery.nn.layers.gcnf import GraphConvattribute
 from graphgallery.nn.layers.misc import SparseConversion, Scale, Sample, Gather
 from graphgallery.nn.layers.dagnn import PropConvolution
