@@ -14,18 +14,18 @@ class GaussionConvolution_F(Layer):
         Tensorflow 1.x implementation: <https://github.com/thumanlab/nrlweb/blob/master/static/assets/download/RGCN.zip>
 
         `GaussionConvolution_F` implements the GaussionConvolution operation
-           where the inputs is node feature matrix and two adjacency matrices,
+           where the inputs is node attribute matrix and two adjacency matrices,
            the output is another distribution (represented with `mean vector` 
            and `variance vector`) 
 
-        Arguments:
+        Parameters:
           units: Positive integer, dimensionality of the output space.
           gamma: Float scalar, determining the attention weights for mean and variance. 
           kl: Float scalar, the hyper-paremeter of KL-divergence loss.
           activation: Activation function to use.
             If you don't specify anything, no activation is applied
             (ie. "linear" activation: `a(x) = x`).
-          use_bias: Boolean, whether the layer uses a bias vector.
+          use_bias: bool, whether the layer uses a bias vector.
           kernel_initializer: Initializer for the `kernel` weights matrix.
           bias_initializer: Initializer for the bias vector.
           kernel_regularizer: Regularizer function applied to
@@ -39,8 +39,8 @@ class GaussionConvolution_F(Layer):
 
         Inputs:
           tuple/list with three 2-D tensor: Tensor `x` and SparseTensor `adj_0, adj_1`: 
-            `[(n_nodes, n_features), (n_nodes, n_nodes), (n_nodes, n_nodes)]`.
-          The former one is the feature matrix (Tensor) and the others are adjacency matrix (SparseTensor) with different normalize rate (-0.5, -1.0).
+            `[(n_nodes, n_attrs), (n_nodes, n_nodes), (n_nodes, n_nodes)]`.
+          The former one is the attribute matrix (Tensor) and the others are adjacency matrix (SparseTensor) with different normalize rate (-0.5, -1.0).
 
         Outputs:
           shape ((n_nodes, units), (n_nodes, units)), two 2-D tensor representing the
@@ -103,24 +103,24 @@ class GaussionConvolution_F(Layer):
 
         KL_divergence = 0.5 * tf.reduce_mean(tf.math.square(mean) + var - tf.math.log(1e-8 + var) - 1, axis=1)
         KL_divergence = tf.reduce_sum(KL_divergence)
-        
+
         # KL loss
         self.add_loss(self.kl*KL_divergence)
 
         attention = tf.exp(-self.gamma*var)
         mean = tf.sparse.sparse_dense_matmul(adj[0], mean * attention)
         var = tf.sparse.sparse_dense_matmul(adj[1], var * attention * attention)
-        
+
         if self.use_bias:
             mean += self.bias_mean
-            var += self.bias_var        
+            var += self.bias_var
 
         return self.activation(mean), self.activation(var)
 
     def get_config(self):
         config = {'units': self.units,
                   'gamma': self.gamma,
-                  'kl': self.kl, 
+                  'kl': self.kl,
                   'activation': activations.serialize(self.activation),
                   'use_bias': self.use_bias,
                   'kernel_initializer': initializers.serialize(
@@ -142,9 +142,9 @@ class GaussionConvolution_F(Layer):
         return {**base_config, **config}
 
     def compute_output_shape(self, input_shapes):
-        features_shape = input_shapes[0]
-        output_shape = (features_shape[0], self.units)
-        return tf.TensorShape(output_shape), tf.TensorShape(output_shape) 
+        attributes_shape = input_shapes[0]
+        output_shape = (attributes_shape[0], self.units)
+        return tf.TensorShape(output_shape), tf.TensorShape(output_shape)
 
 
 class GaussionConvolution_D(Layer):
@@ -158,13 +158,13 @@ class GaussionConvolution_D(Layer):
            and two adjacency matrices, the output is another distribution (represented with `mean vector` 
            and `variance vector`) 
 
-        Arguments:
+        Parameters:
           units: Positive integer, dimensionality of the output space.
           gamma: Float scalar, decide the attention weights for mean and variance. 
           activation: Activation function to use.
             If you don't specify anything, no activation is applied
             (ie. "linear" activation: `a(x) = x`).
-          use_bias: Boolean, whether the layer uses a bias vector.
+          use_bias: bool, whether the layer uses a bias vector.
           kernel_initializer: Initializer for the `kernel` weights matrix.
           bias_initializer: Initializer for the bias vector.
           kernel_regularizer: Regularizer function applied to
@@ -178,7 +178,7 @@ class GaussionConvolution_D(Layer):
 
         Inputs:
           tuple/list with four 2-D tensor: Tensor `mean`, `var` and SparseTensor `adj_0`, `adj_1`: 
-              `[(n_nodes, n_features), (n_nodes, n_features), (n_nodes, n_nodes), (n_nodes, n_nodes)]`.
+              `[(n_nodes, n_attrs), (n_nodes, n_attrs), (n_nodes, n_nodes), (n_nodes, n_nodes)]`.
           The former two is the mean and variance vector (Tensor) and the last are adjacency matrices (SparseTensor) with 
               different normalize rates (-0.5, -1.0).
 
@@ -203,7 +203,7 @@ class GaussionConvolution_D(Layer):
         self.units = units
         self.gamma = gamma
         self.use_bias = use_bias
-        
+
         self.activation = activations.get(activation)
         self.kernel_initializer = initializers.get(kernel_initializer)
         self.bias_initializer = initializers.get(bias_initializer)
@@ -214,9 +214,9 @@ class GaussionConvolution_D(Layer):
         self.bias_constraint = constraints.get(bias_constraint)
 
     def build(self, input_shapes):
-        feature_shape_mean, feature_shape_var = input_shapes[:2]
+        attribute_shape_mean, attribute_shape_var = input_shapes[:2]
 
-        self.kernel_mean = self.add_weight(shape=(feature_shape_mean[1], self.units),
+        self.kernel_mean = self.add_weight(shape=(attribute_shape_mean[1], self.units),
                                            initializer=self.kernel_initializer,
                                            name='kernel_mean',
                                            regularizer=self.kernel_regularizer,
@@ -230,7 +230,7 @@ class GaussionConvolution_D(Layer):
         else:
             self.bias = None
 
-        self.kernel_var = self.add_weight(shape=(feature_shape_var[1], self.units),
+        self.kernel_var = self.add_weight(shape=(attribute_shape_var[1], self.units),
                                           initializer=self.kernel_initializer,
                                           name='kernel_var',
                                           regularizer=self.kernel_regularizer,
@@ -263,7 +263,6 @@ class GaussionConvolution_D(Layer):
 
         return self.activation(mean), self.activation(var)
 
-
     def get_config(self):
         config = {'units': self.units,
                   'gamma': self.gamma,
@@ -288,12 +287,9 @@ class GaussionConvolution_D(Layer):
         return {**base_config, **config}
 
     def compute_output_shape(self, input_shapes):
-        feature_shape_mean, feature_shape_var = input_shapes[:2]
-        
-        output_shape_mean = (feature_shape_mean[0], self.units)
-        output_shape_var = (feature_shape_var[1], self.units)
+        attribute_shape_mean, attribute_shape_var = input_shapes[:2]
 
-        return tf.TensorShape(output_shape_mean), tf.TensorShape(output_shape_var) 
-    
-    
+        output_shape_mean = (attribute_shape_mean[0], self.units)
+        output_shape_var = (attribute_shape_var[1], self.units)
 
+        return tf.TensorShape(output_shape_mean), tf.TensorShape(output_shape_var)
