@@ -21,38 +21,36 @@ class GAT(SemiSupervisedModel):
         Pytorch implementation: <https://github.com/Diego999/pyGAT>
         Keras implementation: <https://github.com/danielegrattarola/keras-gat>
 
-        Arguments:
-        ----------
-            adj: shape (N, N), Scipy sparse matrix if  `is_adj_sparse=True`,
-                Numpy array-like (or matrix) if `is_adj_sparse=False`.
-                The input `symmetric` adjacency matrix, where `N` is the number
-                of nodes in graph.
-            x: shape (N, F), Scipy sparse matrix if `is_x_sparse=True`,
-                Numpy array-like (or matrix) if `is_x_sparse=False`.
-                The input node feature matrix, where `F` is the dimension of features.
-            labels: Numpy array-like with shape (N,)
-                The ground-truth labels for all nodes in graph.
-            norm_adj (Float scalar, optional):
-                The normalize rate for adjacency matrix `adj`. (default: :obj: `None`)
-            norm_x (String, optional):
-                How to normalize the node feature matrix. See `graphgallery.normalize_x`
-                (default :obj: `None`)
-            device (String, optional):
-                The device where the model is running on. You can specified `CPU` or `GPU`
-                for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
-            seed (Positive integer, optional):
-                Used in combination with `tf.random.set_seed` & `np.random.seed` & `random.seed`
-                to create a reproducible sequence of tensors across multiple calls.
-                (default :obj: `None`, i.e., using random seed)
-            name (String, optional):
-                Specified name for the model. (default: :str: `class.__name__`)
-
-
     """
 
     def __init__(self, adj, x, labels, norm_adj=None, norm_x=None,
                  device='CPU:0', seed=None, name=None, **kwargs):
+        """Creat a Graph Attention Networks (GAT) model.
+        Parameters:
+        ----------
+            adj: Scipy.sparse.csr_matrix, shape [n_nodes, n_nodes]
+                The input `symmetric` adjacency matrix in CSR format.
+            x: Numpy.ndarray, shape [n_nodes, n_attrs]. 
+                Node attribute matrix in Numpy format.
+            labels: Numpy.ndarray, shape [n_nodes]
+                Array, where each entry represents respective node's label(s).
+            norm_adj: float scalar. optional
+                The normalize rate for adjacency matrix `adj`. (default: :obj: `None`)
+            norm_x: string. optional
+                How to normalize the node attribute matrix. See `graphgallery.normalize_x`
+                (default :obj: `None`)
+            device: string. optional
+                The device where the model is running on. You can specified `CPU` or `GPU`
+                for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
+            seed: interger scalar. optional 
+                Used in combination with `tf.random.set_seed` & `np.random.seed` 
+                & `random.seed` to create a reproducible sequence of tensors across 
+                multiple calls. (default :obj: `None`, i.e., using random seed)
+            name: string. optional
+                Specified name for the model. (default: :str: `class.__name__`)
+            kwargs: other customed keyword Parameters.
 
+        """
         super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
 
         self.norm_adj = norm_adj
@@ -93,7 +91,7 @@ class GAT(SemiSupervisedModel):
 
         with tf.device(self.device):
 
-            x = Input(batch_shape=[None, self.n_features], dtype=self.floatx, name='features')
+            x = Input(batch_shape=[None, self.n_attrs], dtype=self.floatx, name='attributes')
             adj = Input(batch_shape=[None, None], dtype=self.floatx, sparse=True, name='adj_matrix')
             index = Input(batch_shape=[None],  dtype=self.intx, name='index')
 
