@@ -20,45 +20,47 @@ from graphgallery import astensors, asintarr, normalize_x, normalize_adj, Bunch
 
 class SBVAT(SemiSupervisedModel):
     """
-        Implementation of optimization-based Batch Virtual Adversarial Training  Graph Convolutional Networks (OBVAT). 
-        `Batch Virtual Adversarial Training for Graph Convolutional Networks <https://arxiv.org/abs/1902.09192>`
+        Implementation of sample-based Batch Virtual Adversarial Training 
+        Graph Convolutional Networks (SBVAT). 
+        `Batch Virtual Adversarial Training for Graph Convolutional Networks 
+        <https://arxiv.org/abs/1902.09192>`
         Tensorflow 1.x implementation: <https://github.com/thudzj/BVAT>
 
-        Arguments:
-        ----------
-            adj: shape (N, N), Scipy sparse matrix if  `is_adj_sparse=True`, 
-                Numpy array-like (or matrix) if `is_adj_sparse=False`.
-                The input `symmetric` adjacency matrix, where `N` is the number 
-                of nodes in graph.
-            x: shape (N, F), Scipy sparse matrix if `is_x_sparse=True`, 
-                Numpy array-like (or matrix) if `is_x_sparse=False`.
-                The input node feature matrix, where `F` is the dimension of features.
-            labels: Numpy array-like with shape (N,)
-                The ground-truth labels for all nodes in graph.
-            n_samples (Positive integer, optional): 
-                The number of sampled subset nodes in the graph where the shortest path 
-                length between them is at least 4. (default :obj: `50`)
-            norm_adj (Float scalar, optional): 
-                The normalize rate for adjacency matrix `adj`. (default: :obj:`-0.5`, 
-                i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}}) 
-            norm_x (String, optional): 
-                How to normalize the node feature matrix. See `graphgallery.normalize_x`
-                (default :obj: `None`)
-            device (String, optional): 
-                The device where the model is running on. You can specified `CPU` or `GPU` 
-                for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
-            seed (Positive integer, optional): 
-                Used in combination with `tf.random.set_seed` & `np.random.seed` & `random.seed`  
-                to create a reproducible sequence of tensors across multiple calls. 
-                (default :obj: `None`, i.e., using random seed)
-            name (String, optional): 
-                Specified name for the model. (default: :str: `class.__name__`)
 
     """
 
     def __init__(self, adj, x, labels, n_samples=100,
                  norm_adj=-0.5, norm_x=None, device='CPU:0', seed=None, name=None, **kwargs):
+        """Creat an sample-based Batch Virtual Adversarial Training 
+        Graph Convolutional Networks (SBVAT) model.
 
+        Parameters:
+        ----------
+            adj: Scipy.sparse.csr_matrix, shape [n_nodes, n_nodes]
+                The input `symmetric` adjacency matrix in CSR format.
+            x: Numpy.ndarray, shape [n_nodes, n_attrs]. 
+                Node attribute matrix in Numpy format.
+            labels: Numpy.ndarray, shape [n_nodes]
+                Array, where each entry represents respective node's label(s).
+            n_samples (Positive integer, optional): 
+                The number of sampled subset nodes in the graph where the shortest path 
+                length between them is at least 4. (default :obj: `50`)
+            norm_adj: float scalar. optional 
+                The normalize rate for adjacency matrix `adj`. (default: :obj:`-0.5`, 
+                i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}}) 
+            norm_x: string. optional 
+                How to normalize the node attribute matrix. See `graphgallery.normalize_x`
+                (default :obj: `None`)
+            device: string. optional 
+                The device where the model is running on. You can specified `CPU` or `GPU` 
+                for the model. (default: :str: `CPU:0`, i.e., running on the 0-th `CPU`)
+            seed: interger scalar. optional 
+                Used in combination with `tf.random.set_seed` & `np.random.seed` 
+                & `random.seed` to create a reproducible sequence of tensors across 
+                multiple calls. (default :obj: `None`, i.e., using random seed)
+            name: string. optional
+                Specified name for the model. (default: :str: `class.__name__`)
+        """
         super().__init__(adj, x, labels, device=device, seed=seed, name=name, **kwargs)
 
         self.norm_adj = norm_adj
@@ -98,7 +100,7 @@ class SBVAT(SemiSupervisedModel):
 
         with tf.device(self.device):
 
-            x = Input(batch_shape=[self.n_nodes, self.n_features], dtype=self.floatx, name='features')
+            x = Input(batch_shape=[self.n_nodes, self.n_attrs], dtype=self.floatx, name='attributes')
             adj = Input(batch_shape=[self.n_nodes, self.n_nodes], dtype=self.floatx, sparse=True, name='adj_matrix')
             index = Input(batch_shape=[None],  dtype=self.intx, name='index')
 
