@@ -19,9 +19,9 @@ def sample_mask(indices, shape):
 
 
 def normalize_x(x, norm='l1'):
-    """Normalize the feature matrix with given type.
+    """Normalize the attribute matrix with given type.
 
-    Arguments
+    Parameters
     ----------
     x: Numpy array-like matrix
     norm: The specified type for the normalization.
@@ -33,7 +33,7 @@ def normalize_x(x, norm='l1'):
 
     Returns
     ----------
-        A normalized feature matrix.
+        A normalized attribute matrix.
     """
     if norm not in {'l1', 'l1_0', 'scale', 'robust_scale', None}:
         raise ValueError(f'{norm} is not a supported norm.')
@@ -57,16 +57,16 @@ def normalize_adj(adj_matrics, rate=-0.5, self_loop=1.0):
 
     >>> normalize_adj(adj, rate=-0.5) # return a normalized adjacency matrix
 
-    >>> normalize_adj([adj, adj], rate=[-0.5, 1.0]) # return a list of normalized adjacency matrices
+    # return a list of normalized adjacency matrices
+    >>> normalize_adj([adj, adj], rate=[-0.5, 1.0]) 
 
-
-    Arguments
+    Parameters
     ----------
-    adj_matrics: Scipy matrix, Numpy array-like or list of them 
-        Single or a list of Scipy sparse matrices or Numpy matrices.
-    rate: Single or a list of float scale.
+    adj_matrics: Scipy matrix or a list of them 
+        Single or a list of Scipy sparse matrices.
+    rate: Single or a list of float scale, optional.
         the normalize rate for `adj_matrics`.
-    self_loop: Float scalar.
+    self_loop: float scalar, optional.
         weight of self loops for the adjacency matrix.
 
     Returns
@@ -74,37 +74,29 @@ def normalize_adj(adj_matrics, rate=-0.5, self_loop=1.0):
     Single or a list of Scipy sparse matrix or Numpy matrices.
 
     """
-    def normalize(adj, alpha):
-
-        if sp.isspmatrix(adj) and not sp.isspmatrix_csr(adj):
-            adj = adj.tocsr(copy=False)
+    def normalize(adj, r):
 
+        # here creats a new copy of adj
         adj = adj + self_loop*sp.eye(adj.shape[0])
 
-        if alpha is None:
+        if r is None:
             return adj.astype(config.floatx(), copy=False)
 
-        row_sum = adj.sum(1).A1
-        d_inv_sqrt = np.power(row_sum, alpha)
+        degree = adj.sum(1).A1
+        degree_power = np.power(degree, r)
 
-        if sp.isspmatrix(adj):
-            adj = adj.tocoo(copy=False)
-            adj.data = d_inv_sqrt[adj.row] * adj.data * d_inv_sqrt[adj.col]
-            adj = adj.tocsr(copy=False)
-        else:
-            adj = sp.diags(d_inv_sqrt) @ adj @ sp.diags(d_inv_sqrt)
-            adj = adj.A
+        adj = adj.tocoo(copy=False)
+        adj.data = degree_power[adj.row] * adj.data * degree_power[adj.col]
+        adj = adj.tocsr(copy=False)
 
         return adj.astype(config.floatx(), copy=False)
 
     if is_list_like(adj_matrics) and not isinstance(adj_matrics[0], Number):
         size = len(adj_matrics)
         rate = repeat(rate, size)
-        return [normalize(adj_, rate_) for adj_, rate_ in zip(adj_matrics, rate)]
+        return [normalize(A, r) for A, r in zip(adj_matrics, rate)]
     else:
-        adj_matrics = normalize(adj_matrics, rate)
-
-    return adj_matrics
+        return normalize(adj_matrics, rate)
 
 
 class Bunch(dict):
